
document.addEventListener('DOMContentLoaded', function() {
    var currentStepIndex = 0;
    var steps = document.querySelectorAll('.step');
    var prevBtn = document.querySelector('.form-navigation button[onclick="prevStep()"]');
    var nextBtn = document.querySelector('.form-navigation button[onclick="nextStep()"]');
    var submitBtn = document.getElementById('submitBtn');
    var warningText = document.createElement('p');
    warningText.style.color = 'red';
    warningText.style.display = 'none';
    warningText.innerText = 'Please answer all questions before proceeding.';
    document.getElementById('depressionQuizForm').insertBefore(warningText, document.querySelector('.form-navigation'));

    function showStep(index) {
        // Hide all steps
        steps.forEach(function(step) {
            step.style.display = 'none';
        });

        // Show the current step
        steps[index].style.display = 'block';

        // Reset warning text display
        warningText.style.display = 'none';

        // Show/hide navigation buttons
        if (index === 0) {
            prevBtn.style.display = 'none';
        } else {
            prevBtn.style.display = 'inline';
        }

        if (index === steps.length - 1) {
            nextBtn.style.display = 'none';
            submitBtn.style.display = 'inline';
        } else {
            nextBtn.style.display = 'inline';
            submitBtn.style.display = 'none';
        }
    }

    function isStepValid(step) {
        // Check if all required fields in the step are filled
        var requiredInputs = step.querySelectorAll('input[required]');
        for (var i = 0; i < requiredInputs.length; i++) {
            var input = requiredInputs[i];
            if (input.type === 'checkbox' || input.type === 'radio') {
                var name = input.name;
                var isChecked = step.querySelector('input[name="' + name + '"]:checked');
                if (!isChecked) {
                    return false; // Required question not answered
                }
            } else if (!input.value) {
                return false; // Required input field is empty
            }
        }
        return true; // Step is valid
    }

    window.prevStep = function() {
        if (currentStepIndex > 0) {
            currentStepIndex--;
            showStep(currentStepIndex);
        }
    }

    window.nextStep = function() {
        var currentStep = steps[currentStepIndex];
        if (isStepValid(currentStep)) {
            if (currentStepIndex < steps.length - 1) {
                currentStepIndex++;
                showStep(currentStepIndex);
            }
        } else {
            warningText.style.display = 'block'; // Show warning text
        }
    }

    // Initialize the form with the first step
    showStep(currentStepIndex);
});
	

document.getElementById('depressionQuizForm').addEventListener('submit', function(e) {
    e.preventDefault(); // Prevent the default form submission behavior

    // Calculate the score
    var score = 0;
    var inputs = document.querySelectorAll('#depressionQuizForm input[type="radio"]:checked');
    inputs.forEach(function(input) {
        score += parseInt(input.value, 10);
    });

    // Hide the quiz form
    document.getElementById('depressionQuiz').style.display = 'none';

    // Show the results based on the score
    var results = document.getElementById('results');
    results.style.display = 'block';
    if (score >= 40) {
        document.getElementById('extremeDepression').style.display = 'block';
    } else if (score >= 31) {
        document.getElementById('severeDepression').style.display = 'block';
    } else if (score >= 21) {
        document.getElementById('moderateDepression').style.display = 'block';
    } else if (score >= 17) {
        document.getElementById('borderlineDepression').style.display = 'block';
    } else if (score >= 11) {
        document.getElementById('mildmoodDisturbance').style.display = 'block';
    } else {
        document.getElementById('normal').style.display = 'block';
    }
});	